@@ -1,5 +1,5 @@
 import requests
-from dataCleaning import *
+from .dataCleaning import *
 
 def higherLevelAPI(nameAndTaxaTuple):
     name, taxaDetails = nameAndTaxaTuple
